@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2021 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -78,15 +78,15 @@ sub ambsens_init {
 			push(@last, "RRA:LAST:0.5:1440:" . (365 * $n));
 		}
 		for($n = 0; $n < scalar(my @sl = split(',', $ambsens->{list})); $n++) {
-			push(@tmp, "DS:ambsens" . $n . "_s1:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s2:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s3:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s4:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s5:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s6:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s7:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s8:GAUGE:120:0:U");
-			push(@tmp, "DS:ambsens" . $n . "_s9:GAUGE:120:0:U");
+			push(@tmp, "DS:ambsens" . $n . "_s1:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s2:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s3:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s4:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s5:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s6:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s7:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s8:GAUGE:120:U:U");
+			push(@tmp, "DS:ambsens" . $n . "_s9:GAUGE:120:U:U");
 		}
 		eval {
 			RRDs::create($rrd,
@@ -318,7 +318,7 @@ sub ambsens_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -415,7 +415,7 @@ sub ambsens_cgi {
 		for($n2 = 0; $n2 < $ambsens->{graphs_per_row}; $n2++) {
 			last unless $n < scalar(my @sl = split(',', $ambsens->{list}));
 			if($title) {
-				push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+				push(@output, "    <td>\n");
 			}
 			undef(@tmp);
 			undef(@tmpz);
