@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2021 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -621,6 +621,7 @@ sub apache_update {
 
 		if(!$response->is_success) {
 			logger("$myself: ERROR: Unable to connect to '$url'.");
+			logger("$myself: " . $response->status_line);
 		} else {
 			foreach(split('\n', $response->content)) {
 				if(/^Total Accesses:\s+(\d+)$/) {
@@ -766,7 +767,7 @@ sub apache_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -803,8 +804,8 @@ sub apache_cgi {
 			push(@output, sprintf(" %2d$tf->{tc}", $time));
 			for($n2 = 0; $n2 < scalar(my @al = split(',', $apache->{list})); $n2++) {
 				undef(@row);
-				$from = $n2 * 5;
-				$to = $from + 5;
+				$from = $n2 * 21;
+				$to = $from + 21;
 				push(@row, @$line[$from..$to]);
 				push(@output, sprintf("   %7d  %9d    %4.2f%%   %3d   %3d", @row));
 			}
@@ -857,7 +858,7 @@ sub apache_cgi {
 		@riglim = @{setup_riglim($rigid[0], $limit[0])};
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		undef(@tmp);
 		undef(@tmpz);
@@ -1093,7 +1094,7 @@ sub apache_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		@riglim = @{setup_riglim($rigid[2], $limit[2])};
 		undef(@tmp);
