@@ -57,7 +57,7 @@ sub disk_init {
 				$d =~ s/^(.+?) .*$/$1/;
 	  			next if -e $d;
 				logger("$myself: ERROR: invalid or inexistent device name '$d'.");
-				if(lc($disk->{accept_invalid_disk}) ne "y") {
+				if(lc($disk->{accept_invalid_disk} || "") ne "y") {
 					logger("$myself: 'accept_invalid_disk' option is not set.");
 					logger("$myself: WARNING: initialization aborted.");
 					return;
@@ -366,7 +366,7 @@ sub disk_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -471,17 +471,26 @@ sub disk_cgi {
 		for($n = 0; $n < 8; $n++) {
 			if($d[$n]) {
 				my $dstr = trim($d[$n]);
+				my $base = "";
 				$dstr =~ s/^\"//;
 				$dstr =~ s/\"$//;
 
 				# check if device name is a symbolic link
 				# e.g. /dev/disk/by-path/pci-0000:07:07.0-scsi-0:0:0:0
 				if(-l $dstr) {
+					$base = basename($dstr);
 					$dstr = abs_path(dirname($dstr) . "/" . readlink($dstr));
 					chomp($dstr);
 				}
 
 				$dstr =~ s/^(.+?) .*$/$1/;
+				if($base && defined($disk->{map}->{$base})) {
+					$dstr = $disk->{map}->{$base};
+				} else {
+					if(defined($disk->{map}->{$dstr})) {
+						$dstr = $disk->{map}->{$dstr};
+					}
+				}
 				$str = sprintf("%-20s", $dstr);
 				push(@tmp, "LINE2:temp_" . $n . $LC[$n] . ":$str");
 				push(@tmpz, "LINE2:temp_" . $n . $LC[$n] . ":$dstr");
@@ -498,7 +507,7 @@ sub disk_cgi {
 		}
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		if(lc($config->{temperature_scale}) eq "f") {
 			push(@CDEF, "CDEF:temp_0=9,5,/,temp0,*,32,+");
@@ -608,7 +617,7 @@ sub disk_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		@riglim = @{setup_riglim($rigid[1], $limit[1])};
 		undef(@tmp);
@@ -871,6 +880,17 @@ sub disk_cgi {
 		if($title) {
 			push(@output, "    </td>\n");
 			push(@output, "    </tr>\n");
+
+			if($disk->{desc}->{$k}) {
+				push(@output, "    <tr>\n");
+				push(@output, "      <td bgcolor='$colors->{title_bg_color}' colspan='2'>\n");
+				push(@output, "       <font face='Verdana, sans-serif' color='$colors->{title_fg_color}'>\n");
+				push(@output, "       <font size='-1'>\n");
+				push(@output, "        <b>&nbsp;&nbsp;$disk->{desc}->{$k}<b>\n");
+				push(@output, "       </font></font>\n");
+				push(@output, "      </td>\n");
+				push(@output, "    </tr>\n");
+			}
 			push(@output, main::graph_footer());
 		}
 		$e++;
