@@ -276,7 +276,7 @@ sub ipmi_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -373,7 +373,7 @@ sub ipmi_cgi {
 		for($n2 = 0; $n2 < $ipmi->{graphs_per_row}; $n2++) {
 			last unless $n < scalar(my @sl = split(',', $ipmi->{list}));
 			if($title) {
-				push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+				push(@output, "    <td>\n");
 			}
 			undef(@tmp);
 			undef(@tmpz);
