@@ -456,7 +456,7 @@ sub lmsens_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -660,7 +660,7 @@ sub lmsens_cgi {
 	}
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td valign='bottom' bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	if(lc($config->{temperature_scale}) eq "f") {
 		push(@CDEF, "CDEF:core_0=9,5,/,core0,*,32,+");
@@ -986,7 +986,7 @@ sub lmsens_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[2], $limit[2])};
 	undef(@tmp);
