@@ -779,7 +779,7 @@ sub mail_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -1069,7 +1069,7 @@ sub mail_cgi {
 
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td>\n");
 	}
 	($width, $height) = split('x', $config->{graph_size}->{main});
 	if($silent =~ /imagetag/) {
@@ -1194,10 +1194,18 @@ sub mail_cgi {
 	push(@tmpz, "LINE1:B_in#00EE00");
 	if(lc($config->{netstats_in_bps}) eq "y") {
 		push(@CDEF, "CDEF:B_in=in,8,*");
-		push(@CDEF, "CDEF:B_out=out,8,*");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,8,*,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out,8,*");
+		}
 	} else {
 		push(@CDEF, "CDEF:B_in=in");
-		push(@CDEF, "CDEF:B_out=out");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out");
+		}
 	}
 	if(lc($config->{show_gaps}) eq "y") {
 		push(@tmp, "AREA:wrongdata#$colors->{gap}:");
@@ -1280,7 +1288,7 @@ sub mail_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[2], $limit[2])};
 	undef(@tmp);
