@@ -639,7 +639,7 @@ sub mongodb_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -776,7 +776,7 @@ sub mongodb_cgi {
 		}
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		@riglim = @{setup_riglim($rigid[0], $limit[0])};
 		undef(@tmp);
@@ -1006,7 +1006,7 @@ sub mongodb_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		@riglim = @{setup_riglim($rigid[2], $limit[2])};
 		undef(@tmp);
@@ -1287,10 +1287,18 @@ sub mongodb_cgi {
 		push(@tmpz, "LINE1:B_in#00EE00");
 		if(lc($config->{netstats_in_bps}) eq "y") {
 			push(@CDEF, "CDEF:B_in=in,8,*");
-			push(@CDEF, "CDEF:B_out=out,8,*");
+			if(lc($config->{netstats_mode} || "") eq "separated") {
+				push(@CDEF, "CDEF:B_out=out,8,*,-1,*");
+			} else {
+				push(@CDEF, "CDEF:B_out=out,8,*");
+			}
 		} else {
 			push(@CDEF, "CDEF:B_in=in");
-			push(@CDEF, "CDEF:B_out=out");
+			if(lc($config->{netstats_mode} || "") eq "separated") {
+				push(@CDEF, "CDEF:B_out=out,-1,*");
+			} else {
+				push(@CDEF, "CDEF:B_out=out");
+			}
 		}
 		if(lc($config->{show_gaps}) eq "y") {
 			push(@tmp, "AREA:wrongdata#$colors->{gap}:");
@@ -1393,11 +1401,11 @@ sub mongodb_cgi {
 
 			if($title) {
 				push(@output, "    <tr>\n");
-				push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+				push(@output, "    <td>\n");
 			}
 
 			@riglim = @{setup_riglim($rigid[$e * 6 + $e2], $limit[$e * 6 + $e2])};
-			 undef(@tmp);
+			undef(@tmp);
 			undef(@tmpz);
 			undef(@CDEF);
 			push(@tmp, "LINE2:colls#44EEEE:Collections");
@@ -1489,12 +1497,12 @@ sub mongodb_cgi {
 
 			if($title) {
 				push(@output, "    </td>\n");
-				push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+				push(@output, "    <td>\n");
 			}
 
 			$e2++;
 			@riglim = @{setup_riglim($rigid[$e * 6 + $e2], $limit[$e * 6 + $e2])};
-			 undef(@tmp);
+			undef(@tmp);
 			undef(@tmpz);
 			undef(@CDEF);
 			push(@tmp, "LINE2:dsize#44EEEE:dataSize");
