@@ -547,7 +547,7 @@ sub mysql_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -650,7 +650,7 @@ sub mysql_cgi {
 		@riglim = @{setup_riglim($rigid[0], $limit[0])};
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td valign='top' bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		undef(@tmp);
 		undef(@tmpz);
@@ -937,7 +937,7 @@ sub mysql_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		@riglim = @{setup_riglim($rigid[2], $limit[2])};
 		undef(@tmp);
@@ -1240,10 +1240,18 @@ sub mysql_cgi {
 		push(@tmpz, "LINE1:B_in#00EE00");
 		if(lc($config->{netstats_in_bps}) eq "y") {
 			push(@CDEF, "CDEF:B_in=in,8,*");
-			push(@CDEF, "CDEF:B_out=out,8,*");
+			if(lc($config->{netstats_mode} || "") eq "separated") {
+				push(@CDEF, "CDEF:B_out=out,8,*,-1,*");
+			} else {
+				push(@CDEF, "CDEF:B_out=out,8,*");
+			}
 		} else {
 			push(@CDEF, "CDEF:B_in=in");
-			push(@CDEF, "CDEF:B_out=out");
+			if(lc($config->{netstats_mode} || "") eq "separated") {
+				push(@CDEF, "CDEF:B_out=out,-1,*");
+			} else {
+				push(@CDEF, "CDEF:B_out=out");
+			}
 		}
 		if(lc($config->{show_gaps}) eq "y") {
 			push(@tmp, "AREA:wrongdata#$colors->{gap}:");
