@@ -181,7 +181,7 @@ sub netstat_update {
 	if($config->{os} eq "Linux") {
 		my $cmd = $config->{netstat}->{cmd} || "";
 		if(!$cmd || $cmd eq "ss") {
-			if(open(IN, "ss -na -f inet |")) {
+			if(open(IN, "ss -naut -f inet |")) {
 				while(<IN>) {
 					m/^(\S+)\s+(\S+)/;
 					my $proto = $1 || '';
@@ -205,7 +205,7 @@ sub netstat_update {
 				}
 				close(IN);
 			}
-			if(open(IN, "ss -na -f inet6 |")) {
+			if(open(IN, "ss -naut -f inet6 |")) {
 				while(<IN>) {
 					m/^(\S+)\s+(\S+)/;
 					my $proto = $1 || '';
@@ -402,7 +402,7 @@ sub netstat_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -472,7 +472,7 @@ sub netstat_cgi {
 	if($title) {
 		push(@output, main::graph_header($title, 2));
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td>\n");
 	}
 
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
@@ -728,7 +728,7 @@ sub netstat_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 
 	@riglim = @{setup_riglim($rigid[2], $limit[2])};
