@@ -445,7 +445,7 @@ sub nfss_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -570,7 +570,7 @@ sub nfss_cgi {
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td valign='top' bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	for($n = 0; $n < 10; $n++) {
 		my $str = trim((split(',', $nfss->{graph_0}))[$n]) || "";
@@ -853,7 +853,7 @@ sub nfss_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[3], $limit[3])};
 	undef(@tmp);
