@@ -166,6 +166,7 @@ sub nginx_update {
 
 	if(!$response->is_success) {
 		logger("$myself: ERROR: Unable to connect to '$url'.");
+		logger("$myself: " . $response->status_line);
 	}
 
 	foreach(split('\n', $response->content)) {
@@ -306,7 +307,7 @@ sub nginx_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -376,7 +377,7 @@ sub nginx_cgi {
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td>\n");
 	}
 	push(@tmp, "AREA:total#44EEEE:Total");
 	push(@tmp, "GPRINT:total:LAST:       Current\\: %5.0lf");
@@ -490,7 +491,7 @@ sub nginx_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[1], $limit[1])};
 	undef(@tmp);
@@ -578,16 +579,31 @@ sub nginx_cgi {
 	undef(@warning);
 	my $pnum;
 	if($config->{os} eq "Linux") {
-		open(IN, "netstat -nl --tcp |");
-		while(<IN>) {
-			(undef, undef, undef, $pnum) = split(' ', $_);
-			chomp($pnum);
-			$pnum =~ s/.*://;
-			if($pnum eq $nginx->{port}) {
-				last;
+		my $cmd = $nginx->{cmd} || "";
+		if(!$cmd || $cmd eq "ss") {
+			open(IN, "ss -nl --tcp |");
+			while(<IN>) {
+				(undef, undef, undef, $pnum) = split(' ', $_);
+				chomp($pnum);
+				$pnum =~ s/.*://;
+				if($pnum eq $nginx->{port}) {
+					last;
+				}
 			}
+			close(IN);
+		}
+		if($cmd eq "netstat") {
+			open(IN, "netstat -nl --tcp |");
+			while(<IN>) {
+				(undef, undef, undef, $pnum) = split(' ', $_);
+				chomp($pnum);
+				$pnum =~ s/.*://;
+				if($pnum eq $nginx->{port}) {
+					last;
+				}
+			}
+			close(IN);
 		}
-		close(IN);
 	}
 	if(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD", "NetBSD")) {
 		open(IN, "netstat -anl -p tcp |");
@@ -628,10 +644,18 @@ sub nginx_cgi {
 	push(@tmpz, "LINE1:B_in#00EE00");
 	if(lc($config->{netstats_in_bps}) eq "y") {
 		push(@CDEF, "CDEF:B_in=in,8,*");
-		push(@CDEF, "CDEF:B_out=out,8,*");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,8,*,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out,8,*");
+		}
 	} else {
 		push(@CDEF, "CDEF:B_in=in");
-		push(@CDEF, "CDEF:B_out=out");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out");
+		}
 	}
 	if(lc($config->{show_gaps}) eq "y") {
 		push(@tmp, "AREA:wrongdata#$colors->{gap}:");
