@@ -261,7 +261,7 @@ sub ntp_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -386,7 +386,7 @@ sub ntp_cgi {
 		push(@tmpz, "LINE2:ntp" . $e . "_jit#EE4444:Jitter");
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td>\n");
 		}
 		if(lc($config->{show_gaps}) eq "y") {
 			push(@tmp, "AREA:wrongdata_p#$colors->{gap}:");
@@ -472,7 +472,7 @@ sub ntp_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		@riglim = @{setup_riglim($rigid[1], $limit[1])};
 		undef(@tmp);
