@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2021 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -303,7 +303,7 @@ sub nut_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -338,8 +338,8 @@ sub nut_cgi {
 			push(@output, sprintf(" %2d$tf->{tc}", $time));
 			for($n2 = 0; $n2 < scalar(my @pl = split(',', $nut->{list})); $n2++) {
 				undef(@row);
-				$from = $n2 * 22;
-				$to = $from + 22;
+				$from = $n2 * 21;
+				$to = $from + 21;
 				my ($ltran, $htran, $ivolt, $ovolt, $bchar, $loadc, $mbatc, undef, $atemp, $itemp, $humid, $battv, $nomba, $timel, $minti, $linef) = @$line[$from..$to];
 				$itemp = celsius_to($config, $itemp);
 				$atemp = celsius_to($config, $atemp);
@@ -436,7 +436,7 @@ sub nut_cgi {
 		@riglim = @{setup_riglim($rigid[0], $limit[0])};
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td valign='top' bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		undef(@tmp);
 		undef(@tmpz);
@@ -650,7 +650,7 @@ sub nut_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 
 		@riglim = @{setup_riglim($rigid[2], $limit[2])};
