@@ -339,7 +339,7 @@ sub nvidia_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -439,7 +439,7 @@ sub nvidia_cgi {
 
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td>\n");
 	}
 	if(lc($config->{temperature_scale}) eq "f") {
 		push(@CDEF, "CDEF:temp_0=9,5,/,temp0,*,32,+");
@@ -552,7 +552,7 @@ sub nvidia_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[1], $limit[1])};
 	undef(@tmp);
