@@ -157,6 +157,7 @@ sub phpapc_update {
 
 		if(!$response->is_success) {
 			logger("$myself: ERROR: Unable to connect to '$pls'.");
+			logger("$myself: " . $response->status_line);
 		}
 
 		$data =~ s/\n//g;
@@ -252,7 +253,7 @@ sub phpapc_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -363,7 +364,7 @@ sub phpapc_cgi {
 		@riglim = @{setup_riglim($rigid[0], $limit[0])};
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		undef(@tmp);
 		undef(@tmpz);
@@ -474,7 +475,7 @@ sub phpapc_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 		@riglim = @{setup_riglim($rigid[1], $limit[1])};
 		undef(@tmp);
