@@ -154,13 +154,7 @@ sub phpfpm_update {
 
 	foreach my $pfg (sort keys %{$phpfpm->{group}}) {
 		my @pfl = split(',', $phpfpm->{list}->{$pfg});
-		if(!scalar(@pfl)) {
-			for($n = 0; $n < 8; $n++) {
-				$rrdata .= ":0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0";
-			}
-			next;
-		}
-		for($n = 0; $n < 8; $n++) {
+		for($n = 0; $n < 8 && $n < scalar(@pfl); $n++) {
 			my $uptim = 0;
 			my $aconn = 0;
 			my $lqueu = 0;
@@ -180,13 +174,15 @@ sub phpfpm_update {
 				next;
 			}
 
-			$ssl = "ssl_opts => {verify_hostname => 0}"
+			$ssl = "ssl_opts => {verify_hostname => 0}",
+			$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0
 				if lc($config->{accept_selfsigned_certs}) eq "y";
 			my $ua = LWP::UserAgent->new(timeout => 30, $ssl);
 			$ua->agent($config->{user_agent_id}) if $config->{user_agent_id} || "";
 			my $response = $ua->request(HTTP::Request->new('GET', $url));
 			if(!$response->is_success) {
 				logger("$myself: ERROR: in pool '$pool', unable to connect to '$url'.");
+				logger("$myself: " . $response->status_line);
 			} else {
 				foreach(split('\n', $response->content)) {
 					if(/^start since:\s+(\d+)$/) {
@@ -224,6 +220,9 @@ sub phpfpm_update {
 			}
 			$rrdata .= ":$uptim:$aconn:$lqueu:$mlque:$iproc:$aproc:$mapro:$mchil:$slreq:0:0:0:0:0:0:0:0:0";
 		}
+		for(; $n < 8; $n++) {
+			$rrdata .= ":0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0";
+		}
 	}
 
 	RRDs::update($rrd, $rrdata);
@@ -300,7 +299,7 @@ sub phpfpm_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -403,9 +402,11 @@ sub phpfpm_cgi {
 	}
 
 	my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+		"--resolution=60",
 		"--start=-1min",
-		"AVERAGE",
-		"-r 60");
+		"AVERAGE");
+	$err = RRDs::error;
+	push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 	my $line = @$data[0];
 	my ($uptime) = @$line[0];	# all pools have the same uptime
 	my $uptimeline;
@@ -449,16 +450,14 @@ sub phpfpm_cgi {
 
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td>\n");
 		}
 		if(lc($config->{show_gaps}) eq "y") {
 			push(@tmp, "AREA:wrongdata#$colors->{gap}:");
 			push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
 			push(@CDEF, "CDEF:wrongdata=allvalues,UN,INF,UNKN,IF");
 		}
-		for($n = 0; $n < scalar(@pfl) / 2; $n++) {
-			push(@tmp, "COMMENT: \\n");
-		}
+		push(@tmp, "COMMENT: \\n");
 		($width, $height) = split('x', $config->{graph_size}->{main});
 		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 6]",
 			"--title=$config->{graphs}->{_phpfpm1}  ($tf->{nwhen}$tf->{twhen})",
@@ -554,9 +553,7 @@ sub phpfpm_cgi {
 			push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
 			push(@CDEF, "CDEF:wrongdata=allvalues,UN,INF,UNKN,IF");
 		}
-		for($n = 0; $n < scalar(@pfl) / 2; $n++) {
-			push(@tmp, "COMMENT: \\n");
-		}
+		push(@tmp, "COMMENT: \\n");
 		($width, $height) = split('x', $config->{graph_size}->{main});
 		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 6 + 1]",
 			"--title=$config->{graphs}->{_phpfpm2}  ($tf->{nwhen}$tf->{twhen})",
@@ -633,7 +630,7 @@ sub phpfpm_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 
 		@riglim = @{setup_riglim($rigid[2], $limit[2])};
