@@ -392,7 +392,7 @@ sub port_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -521,7 +521,7 @@ sub port_cgi {
 		my $pc = trim((split(',', $port->{desc}->{$pl[$n]}))[2]);
 		foreach my $pcon (split('/', $pc)) {
 			if($title) {
-				push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+				push(@output, "    <td>\n");
 			}
 			my $pnum;
 			$pl[$n] = trim($pl[$n]);
@@ -538,16 +538,31 @@ sub port_cgi {
 			undef(@warning);
 			if(uc($plis || "") eq "L") {
 				if($config->{os} eq "Linux") {
-					open(IN, "netstat -nl --$pp |");
-					while(<IN>) {
-						(undef, undef, undef, $pnum) = split(' ', $_);
-						chomp($pnum);
-						$pnum =~ s/.*://;
-						if($pnum eq $num) {
-							last;
+					my $cmd = $port->{cmd} || "";
+					if(!$cmd || $cmd eq "ss") {
+						open(IN, "ss -nl --$pp |");
+						while(<IN>) {
+							(undef, undef, undef, $pnum) = split(' ', $_);
+							chomp($pnum);
+							$pnum =~ s/.*://;
+							if($pnum eq $num) {
+								last;
+							}
 						}
+						close(IN);
+					}
+					if($cmd eq "netstat") {
+						open(IN, "netstat -nl --$pp |");
+						while(<IN>) {
+							(undef, undef, undef, $pnum) = split(' ', $_);
+							chomp($pnum);
+							$pnum =~ s/.*://;
+							if($pnum eq $num) {
+								last;
+							}
+						}
+						close(IN);
 					}
-					close(IN);
 				}
 				if(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD")) {
 					open(IN, "netstat -anl -p $pp |");
@@ -590,10 +605,18 @@ sub port_cgi {
 				push(@tmpz, "LINE1:B_i_in#00EE00");
 				if(lc($config->{netstats_in_bps}) eq "y") {
 					push(@CDEF, "CDEF:B_i_in=i_in,8,*");
-					push(@CDEF, "CDEF:B_i_out=i_out,8,*");
+					if(lc($config->{netstats_mode} || "") eq "separated") {
+						push(@CDEF, "CDEF:B_i_out=i_out,8,*,-1,*");
+					} else {
+						push(@CDEF, "CDEF:B_i_out=i_out,8,*");
+					}
 				} else {
 					push(@CDEF, "CDEF:B_i_in=i_in");
-					push(@CDEF, "CDEF:B_i_out=i_out");
+					if(lc($config->{netstats_mode} || "") eq "separated") {
+						push(@CDEF, "CDEF:B_i_out=i_out,-1,*");
+					} else {
+						push(@CDEF, "CDEF:B_i_out=i_out");
+					}
 				}
 			}
 			if(lc($pcon) eq "out") {
@@ -611,10 +634,18 @@ sub port_cgi {
 				push(@tmpz, "LINE1:B_o_in#00EE00");
 				if(lc($config->{netstats_in_bps}) eq "y") {
 					push(@CDEF, "CDEF:B_o_in=o_in,8,*");
-					push(@CDEF, "CDEF:B_o_out=o_out,8,*");
+					if(lc($config->{netstats_mode} || "") eq "separated") {
+						push(@CDEF, "CDEF:B_o_out=o_out,8,*,-1,*");
+					} else {
+						push(@CDEF, "CDEF:B_o_out=o_out,8,*");
+					}
 				} else {
 					push(@CDEF, "CDEF:B_o_in=o_in");
-					push(@CDEF, "CDEF:B_o_out=o_out");
+					if(lc($config->{netstats_mode} || "") eq "separated") {
+						push(@CDEF, "CDEF:B_o_out=o_out,-1,*");
+					} else {
+						push(@CDEF, "CDEF:B_o_out=o_out");
+					}
 				}
 			}
 			if(lc($config->{show_gaps}) eq "y") {
@@ -622,7 +653,8 @@ sub port_cgi {
 				push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
 				push(@CDEF, "CDEF:wrongdata=allvalues,UN,INF,UNKN,IF");
 			}
-			($width, $height) = split('x', $config->{graph_size}->{mini});
+			$port->{size} = "mini" if !defined($port->{size});
+			($width, $height) = split('x', $config->{graph_size}->{$port->{size}});
 			if($silent =~ /imagetag/) {
 				($width, $height) = split('x', $config->{graph_size}->{remote}) if $silent eq "imagetag";
 				($width, $height) = split('x', $config->{graph_size}->{main}) if $silent eq "imagetagbig";
