@@ -544,7 +544,7 @@ sub squid_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -734,7 +734,7 @@ sub squid_cgi {
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td valign='top' bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	my @sg0 = split(',', $squid->{graph_0});
 	for($n = 0, $i = 1; $n < 9; $n++, $i++) {
@@ -742,7 +742,7 @@ sub squid_cgi {
 			$str = sprintf("%-34s", trim($sg0[$n]));
 			$str = substr($str, 0, 23);
 			push(@DEF, "DEF:squid_g1_$i=$rrd:squid_g1_$i:AVERAGE");
-			push(@tmp, "LINE1:squid_g1_$i$AC[$n]:$str");
+			push(@tmp, "LINE2:squid_g1_$i$AC[$n]:$str");
 			push(@tmp, "GPRINT:squid_g1_$i:LAST:Cur\\: %6.1lf");
 			push(@tmp, "GPRINT:squid_g1_$i:AVERAGE:  Avg\\: %6.1lf");
 			push(@tmp, "GPRINT:squid_g1_$i:MIN:  Min\\: %6.1lf");
@@ -838,7 +838,7 @@ sub squid_cgi {
 			$str = sprintf("%-34s", trim($sg1[$n]));
 			$str = substr($str, 0, 23);
 			push(@DEF, "DEF:squid_g2_$i=$rrd:squid_g2_$i:AVERAGE");
-			push(@tmp, "LINE1:squid_g2_$i$AC[$n]:$str");
+			push(@tmp, "LINE2:squid_g2_$i$AC[$n]:$str");
 			push(@tmp, "GPRINT:squid_g2_$i:LAST:Cur\\: %6.1lf");
 			push(@tmp, "GPRINT:squid_g2_$i:AVERAGE:  Avg\\: %6.1lf");
 			push(@tmp, "GPRINT:squid_g2_$i:MIN:  Min\\: %6.1lf");
@@ -925,42 +925,42 @@ sub squid_cgi {
 	undef(@tmp);
 	undef(@tmpz);
 	undef(@CDEF);
-	push(@tmp, "LINE1:squid_rq_1$AC[0]:Client HTTP requests");
+	push(@tmp, "LINE2:squid_rq_1$AC[0]:Client HTTP requests");
 	push(@tmp, "GPRINT:squid_rq_1:LAST:  Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_1:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_1:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_1:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_2$AC[1]:Client HTTP hits");
+	push(@tmp, "LINE2:squid_rq_2$AC[1]:Client HTTP hits");
 	push(@tmp, "GPRINT:squid_rq_2:LAST:      Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_2:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_2:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_2:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_3$AC[2]:Server HTTP requests");
+	push(@tmp, "LINE2:squid_rq_3$AC[2]:Server HTTP requests");
 	push(@tmp, "GPRINT:squid_rq_3:LAST:  Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_3:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_3:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_3:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_4$AC[3]:Server FTP requests");
+	push(@tmp, "LINE2:squid_rq_4$AC[3]:Server FTP requests");
 	push(@tmp, "GPRINT:squid_rq_4:LAST:   Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_4:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_4:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_4:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_5$AC[4]:Server Other requests");
+	push(@tmp, "LINE2:squid_rq_5$AC[4]:Server Other requests");
 	push(@tmp, "GPRINT:squid_rq_5:LAST: Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_5:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_5:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_5:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_6$AC[5]:Aborted requests");
+	push(@tmp, "LINE2:squid_rq_6$AC[5]:Aborted requests");
 	push(@tmp, "GPRINT:squid_rq_6:LAST:      Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_6:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_6:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_6:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_7$AC[6]:Swap files cleaned");
+	push(@tmp, "LINE2:squid_rq_7$AC[6]:Swap files cleaned");
 	push(@tmp, "GPRINT:squid_rq_7:LAST:    Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_7:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_7:MIN:  Min\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_7:MAX:  Max\\: %6.1lf\\n");
-	push(@tmp, "LINE1:squid_rq_8$AC[7]:Unlink requests");
+	push(@tmp, "LINE2:squid_rq_8$AC[7]:Unlink requests");
 	push(@tmp, "GPRINT:squid_rq_8:LAST:       Cur\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_8:AVERAGE:  Avg\\: %6.1lf");
 	push(@tmp, "GPRINT:squid_rq_8:MIN:  Min\\: %6.1lf");
@@ -1062,18 +1062,18 @@ sub squid_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[3], $limit[3])};
 	undef(@tmp);
 	undef(@tmpz);
 	undef(@CDEF);
-	push(@tmp, "LINE1:m_alloc#EEEE44:Allocated");
-	push(@tmp, "GPRINT:m_alloc:LAST:            Current\\: %7.1lf\\n");
+	push(@tmp, "LINE2:m_alloc#EEEE44:Allocated");
+	push(@tmp, "GPRINT:m_alloc:LAST:            Current\\: %6.1lf%s\\n");
 	push(@tmp, "AREA:m_inuse#44AAEE:In use");
-	push(@tmp, "LINE1:m_inuse#00AAEE:");
-	push(@tmp, "GPRINT:m_inuse:LAST:               Current\\: %7.1lf\\n");
-	push(@tmp, "GPRINT:m_perc:LAST:                          In use\\:   %5.1lf%%\\n");
+	push(@tmp, "LINE2:m_inuse#00AAEE:");
+	push(@tmp, "GPRINT:m_inuse:LAST:               Current\\: %6.1lf%s\\n");
+	push(@tmp, "GPRINT:m_perc:LAST:                          In use\\:   %4.1lf%%\\n");
 	push(@tmpz, "LINE2:m_alloc#EEEE44:Allocated");
 	push(@tmpz, "AREA:m_inuse#44AAEE:In use");
 	push(@tmpz, "LINE2:m_inuse#00AAEE:");
@@ -1095,7 +1095,7 @@ sub squid_cgi {
 		"--title=$config->{graphs}->{_squid4}  ($tf->{nwhen}$tf->{twhen})",
 		"--start=-$tf->{nwhen}$tf->{twhen}",
 		"--imgformat=$imgfmt_uc",
-		"--vertical-label=Megabytes",
+		"--vertical-label=bytes",
 		"--width=$width",
 		"--height=$height",
 		@extra,
@@ -1106,8 +1106,8 @@ sub squid_cgi {
 		@{$colors->{graph_colors}},
 		"DEF:squid_m_1=$rrd:squid_m_1:AVERAGE",
 		"DEF:squid_m_2=$rrd:squid_m_2:AVERAGE",
-		"CDEF:m_alloc=squid_m_1,1024,/",
-		"CDEF:m_inuse=squid_m_2,1024,/",
+		"CDEF:m_alloc=squid_m_1,1024,*",
+		"CDEF:m_inuse=squid_m_2,1024,*",
 		"CDEF:m_perc=squid_m_2,100,*,squid_m_1,/",
 		"CDEF:allvalues=squid_m_1,squid_m_2,+",
 		@CDEF,
@@ -1120,7 +1120,7 @@ sub squid_cgi {
 			"--title=$config->{graphs}->{_squid4}  ($tf->{nwhen}$tf->{twhen})",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
 			"--imgformat=$imgfmt_uc",
-			"--vertical-label=Megabytes",
+			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
 			@extra,
@@ -1131,8 +1131,8 @@ sub squid_cgi {
 			@{$colors->{graph_colors}},
 			"DEF:squid_m_1=$rrd:squid_m_1:AVERAGE",
 			"DEF:squid_m_2=$rrd:squid_m_2:AVERAGE",
-			"CDEF:m_alloc=squid_m_1,1024,/",
-			"CDEF:m_inuse=squid_m_2,1024,/",
+			"CDEF:m_alloc=squid_m_1,1024,*",
+			"CDEF:m_inuse=squid_m_2,1024,*",
 			"CDEF:m_perc=squid_m_2,100,*,squid_m_1,/",
 			"CDEF:allvalues=squid_m_1,squid_m_2,+",
 			@CDEF,
@@ -1163,12 +1163,12 @@ sub squid_cgi {
 	undef(@tmp);
 	undef(@tmpz);
 	undef(@CDEF);
-	push(@tmp, "LINE1:s_alloc#EEEE44:Allocated");
-	push(@tmp, "GPRINT:s_alloc:LAST:            Current\\: %7.1lf\\n");
+	push(@tmp, "LINE2:s_alloc#EEEE44:Allocated");
+	push(@tmp, "GPRINT:s_alloc:LAST:            Current\\: %6.1lf%s\\n");
 	push(@tmp, "AREA:s_inuse#44AAEE:In use");
-	push(@tmp, "GPRINT:s_inuse:LAST:               Current\\: %7.1lf\\n");
-	push(@tmp, "LINE1:s_inuse#00AAEE:");
-	push(@tmp, "GPRINT:s_perc:LAST:                          In use\\:   %5.1lf%%\\n");
+	push(@tmp, "GPRINT:s_inuse:LAST:               Current\\: %6.1lf%s\\n");
+	push(@tmp, "LINE2:s_inuse#00AAEE:");
+	push(@tmp, "GPRINT:s_perc:LAST:                          In use\\:   %4.1lf%%\\n");
 	push(@tmpz, "LINE2:s_alloc#EEEE44:Allocated");
 	push(@tmpz, "AREA:s_inuse#44AAEE:In use");
 	push(@tmpz, "LINE2:s_inuse#00AAEE:");
@@ -1190,7 +1190,7 @@ sub squid_cgi {
 		"--title=$config->{graphs}->{_squid5}  ($tf->{nwhen}$tf->{twhen})",
 		"--start=-$tf->{nwhen}$tf->{twhen}",
 		"--imgformat=$imgfmt_uc",
-		"--vertical-label=Megabytes",
+		"--vertical-label=bytes",
 		"--width=$width",
 		"--height=$height",
 		@extra,
@@ -1201,8 +1201,8 @@ sub squid_cgi {
 		@{$colors->{graph_colors}},
 		"DEF:squid_s_2=$rrd:squid_s_2:AVERAGE",
 		"DEF:squid_s_3=$rrd:squid_s_3:AVERAGE",
-		"CDEF:s_alloc=squid_s_2,1024,/",
-		"CDEF:s_inuse=squid_s_3,1024,/",
+		"CDEF:s_alloc=squid_s_2,1024,*",
+		"CDEF:s_inuse=squid_s_3,1024,*",
 		"CDEF:s_perc=squid_s_3,100,*,squid_s_2,/",
 		"CDEF:allvalues=squid_s_2,squid_s_3,+",
 		@CDEF,
@@ -1215,7 +1215,7 @@ sub squid_cgi {
 			"--title=$config->{graphs}->{_squid5}  ($tf->{nwhen}$tf->{twhen})",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
 			"--imgformat=$imgfmt_uc",
-			"--vertical-label=Megabytes",
+			"--vertical-label=bytes",
 			"--width=$width",
 			"--height=$height",
 			@extra,
@@ -1226,8 +1226,8 @@ sub squid_cgi {
 			@{$colors->{graph_colors}},
 			"DEF:squid_s_2=$rrd:squid_s_2:AVERAGE",
 			"DEF:squid_s_3=$rrd:squid_s_3:AVERAGE",
-			"CDEF:s_alloc=squid_s_2,1024,/",
-			"CDEF:s_inuse=squid_s_3,1024,/",
+			"CDEF:s_alloc=squid_s_2,1024,*",
+			"CDEF:s_inuse=squid_s_3,1024,*",
 			"CDEF:s_perc=squid_s_3,100,*,squid_s_2,/",
 			"CDEF:allvalues=squid_s_2,squid_s_3,+",
 			@CDEF,
@@ -1264,15 +1264,15 @@ sub squid_cgi {
 	push(@tmp, "GPRINT:ic_hits:LAST:                 Current\\: %7.1lf\\n");
 	push(@tmp, "AREA:ic_misses#EE44EE:Misses");
 	push(@tmp, "GPRINT:ic_misses:LAST:               Current\\: %7.1lf\\n");
-	push(@tmp, "LINE1:ic_requests#00EEEE");
-	push(@tmp, "LINE1:ic_hits#0000EE");
-	push(@tmp, "LINE1:ic_misses#EE00EE");
+	push(@tmp, "LINE2:ic_requests#00EEEE");
+	push(@tmp, "LINE2:ic_hits#0000EE");
+	push(@tmp, "LINE2:ic_misses#EE00EE");
 	push(@tmpz, "AREA:ic_requests#44EEEE:Requests");
 	push(@tmpz, "AREA:ic_hits#4444EE:Hits");
 	push(@tmpz, "AREA:ic_misses#EE44EE:Misses");
-	push(@tmpz, "LINE1:ic_requests#00EEEE");
-	push(@tmpz, "LINE1:ic_hits#0000EE");
-	push(@tmpz, "LINE1:ic_misses#EE00EE");
+	push(@tmpz, "LINE2:ic_requests#00EEEE");
+	push(@tmpz, "LINE2:ic_hits#0000EE");
+	push(@tmpz, "LINE2:ic_misses#EE00EE");
 	if(lc($config->{show_gaps}) eq "y") {
 		push(@tmp, "AREA:wrongdata#$colors->{gap}:");
 		push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
@@ -1363,18 +1363,18 @@ sub squid_cgi {
 	push(@tmp, "GPRINT:io_gopher:LAST:               Current\\: %7.1lf\\n");
 	push(@tmp, "AREA:io_wais#EEEE44:WAIS");
 	push(@tmp, "GPRINT:io_wais:LAST:                 Current\\: %7.1lf\\n");
-	push(@tmp, "LINE1:io_http#00EEEE");
-	push(@tmp, "LINE1:io_ftp#0000EE");
-	push(@tmp, "LINE1:io_gopher#EE00EE");
-	push(@tmp, "LINE1:io_wais#EEEE00");
+	push(@tmp, "LINE2:io_http#00EEEE");
+	push(@tmp, "LINE2:io_ftp#0000EE");
+	push(@tmp, "LINE2:io_gopher#EE00EE");
+	push(@tmp, "LINE2:io_wais#EEEE00");
 	push(@tmpz, "AREA:io_http#44EEEE:HTTP");
 	push(@tmpz, "AREA:io_ftp#4444EE:FTP");
 	push(@tmpz, "AREA:io_gopher#EE44EE:Gopher");
 	push(@tmpz, "AREA:io_wais#EEEE44:WAIS");
-	push(@tmpz, "LINE1:io_http#44EEEE");
-	push(@tmpz, "LINE1:io_ftp#4444EE");
-	push(@tmpz, "LINE1:io_gopher#EE44EE");
-	push(@tmpz, "LINE1:io_wais#EEEE44");
+	push(@tmpz, "LINE2:io_http#44EEEE");
+	push(@tmpz, "LINE2:io_ftp#4444EE");
+	push(@tmpz, "LINE2:io_gopher#EE44EE");
+	push(@tmpz, "LINE2:io_wais#EEEE44");
 	if(lc($config->{show_gaps}) eq "y") {
 		push(@tmp, "AREA:wrongdata#$colors->{gap}:");
 		push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
@@ -1463,20 +1463,28 @@ sub squid_cgi {
 	push(@tmp, "AREA:B_out#4444EE:Output");
 	push(@tmp, "AREA:B_out#4444EE:");
 	push(@tmp, "AREA:B_in#44EE44:");
-	push(@tmp, "LINE1:B_out#0000EE");
-	push(@tmp, "LINE1:B_in#00EE00");
+	push(@tmp, "LINE2:B_out#0000EE");
+	push(@tmp, "LINE2:B_in#00EE00");
 	push(@tmpz, "AREA:B_in#44EE44:Input");
 	push(@tmpz, "AREA:B_out#4444EE:Output");
 	push(@tmpz, "AREA:B_out#4444EE:");
 	push(@tmpz, "AREA:B_in#44EE44:");
-	push(@tmpz, "LINE1:B_out#0000EE");
-	push(@tmpz, "LINE1:B_in#00EE00");
+	push(@tmpz, "LINE2:B_out#0000EE");
+	push(@tmpz, "LINE2:B_in#00EE00");
 	if(lc($config->{netstats_in_bps}) eq "y") {
 		push(@CDEF, "CDEF:B_in=in,8,*");
-		push(@CDEF, "CDEF:B_out=out,8,*");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,8,*,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out,8,*");
+		}
 	} else {
 		push(@CDEF, "CDEF:B_in=in");
-		push(@CDEF, "CDEF:B_out=out");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out");
+		}
 	}
 	if(lc($config->{show_gaps}) eq "y") {
 		push(@tmp, "AREA:wrongdata#$colors->{gap}:");
@@ -1562,20 +1570,28 @@ sub squid_cgi {
 	push(@tmp, "AREA:B_out#4444EE:Output");
 	push(@tmp, "AREA:B_out#4444EE:");
 	push(@tmp, "AREA:B_in#44EE44:");
-	push(@tmp, "LINE1:B_out#0000EE");
-	push(@tmp, "LINE1:B_in#00EE00");
+	push(@tmp, "LINE2:B_out#0000EE");
+	push(@tmp, "LINE2:B_in#00EE00");
 	push(@tmpz, "AREA:B_in#44EE44:Input");
 	push(@tmpz, "AREA:B_out#4444EE:Output");
 	push(@tmpz, "AREA:B_out#4444EE:");
 	push(@tmpz, "AREA:B_in#44EE44:");
-	push(@tmpz, "LINE1:B_out#0000EE");
-	push(@tmpz, "LINE1:B_in#00EE00");
+	push(@tmpz, "LINE2:B_out#0000EE");
+	push(@tmpz, "LINE2:B_in#00EE00");
 	if(lc($config->{netstats_in_bps}) eq "y") {
 		push(@CDEF, "CDEF:B_in=in,8,*");
-		push(@CDEF, "CDEF:B_out=out,8,*");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,8,*,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out,8,*");
+		}
 	} else {
 		push(@CDEF, "CDEF:B_in=in");
-		push(@CDEF, "CDEF:B_out=out");
+		if(lc($config->{netstats_mode} || "") eq "separated") {
+			push(@CDEF, "CDEF:B_out=out,-1,*");
+		} else {
+			push(@CDEF, "CDEF:B_out=out");
+		}
 	}
 	if(lc($config->{show_gaps}) eq "y") {
 		push(@tmp, "AREA:wrongdata#$colors->{gap}:");
