@@ -489,7 +489,7 @@ sub system_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td >\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch($rrd,
 			"--resolution=$tf->{res}",
@@ -574,7 +574,7 @@ sub system_cgi {
 	}
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td >\n");
 	}
 	push(@tmp, "AREA:load1#4444EE: 1 min average");
 	push(@tmp, "GPRINT:load1:LAST:  Current\\: %4.2lf");
@@ -720,7 +720,6 @@ sub system_cgi {
 		@extra,
 		$zoom,
 		@{$cgi->{version12}},
-		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
 		"DEF:mtotl=$rrd:system_mtotl:AVERAGE",
 		"DEF:mbuff=$rrd:system_mbuff:AVERAGE",
@@ -756,7 +755,6 @@ sub system_cgi {
 			@extra,
 			$zoom,
 			@{$cgi->{version12}},
-			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
 			"DEF:mtotl=$rrd:system_mtotl:AVERAGE",
 			"DEF:mbuff=$rrd:system_mbuff:AVERAGE",
@@ -797,7 +795,7 @@ sub system_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 
 	@riglim = @{setup_riglim($rigid[2], $limit[2])};
