@@ -211,7 +211,7 @@ sub user_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -275,7 +275,7 @@ sub user_cgi {
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td>\n");
 	}
 	push(@tmp, "AREA:sys#44EE44:Logged In");
 	push(@tmp, "GPRINT:sys:LAST:        Current\\: %3.0lf");
@@ -360,7 +360,7 @@ sub user_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[1], $limit[1])};
 	undef(@tmp);
