@@ -421,7 +421,7 @@ sub varnish_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -518,7 +518,7 @@ sub varnish_cgi {
 	if($title) {
 		push(@output, main::graph_header($title, 2));
 		push(@output, "    <tr>\n");
-		push(@output, "    <td valign='top' bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
@@ -784,7 +784,7 @@ sub varnish_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 
 	@riglim = @{setup_riglim($rigid[2], $limit[2])};
