@@ -284,7 +284,8 @@ sub wowza_update {
 		my $data = XMLin($response->content);
 
 		if(!$response->is_success) {
-			logger("$myself: ERROR: Unable to connect to '$wls' (" . $response->status_line . ").");
+			logger("$myself: ERROR: Unable to connect to '$wls'.");
+			logger("$myself: " . $response->status_line);
 		}
 
 		# main (VHost) stats
@@ -470,7 +471,7 @@ sub wowza_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -576,9 +577,11 @@ sub wowza_cgi {
 
 		@riglim = @{setup_riglim($rigid[0], $limit[0])};
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
+			"--resolution=60",
 			"--start=-1min",
-			"AVERAGE",
-			"-r 60");
+			"AVERAGE");
+		$err = RRDs::error;
+		push(@output, "ERROR: while fetching $rrd: $err\n") if $err;
 		my $line = @$data[0];
 		my ($uptime) = @$line[$e * 130];
 		my $uptimeline;
@@ -606,7 +609,7 @@ sub wowza_cgi {
 
 		if($title) {
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td>\n");
 		}
 		if(lc($config->{show_gaps}) eq "y") {
 			push(@tmp, "AREA:wrongdata#$colors->{gap}:");
@@ -810,7 +813,7 @@ sub wowza_cgi {
 
 		if($title) {
 			push(@output, "    </td>\n");
-			push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
 		}
 
 		@riglim = @{setup_riglim($rigid[2], $limit[2])};
