@@ -450,7 +450,7 @@ sub zfs_cgi {
 		if($title) {
 			push(@output, main::graph_header($title, 2));
 			push(@output, "    <tr>\n");
-			push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+			push(@output, "    <td>\n");
 		}
 		my (undef, undef, undef, $data) = RRDs::fetch("$rrd",
 			"--resolution=$tf->{res}",
@@ -552,7 +552,7 @@ sub zfs_cgi {
 	@riglim = @{setup_riglim($rigid[0], $limit[0])};
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='$colors->{title_bg_color}'>\n");
+		push(@output, "    <td>\n");
 	}
 	push(@tmp, "LINE2:arcsize#44EE44:ARC size");
 	push(@tmp, "GPRINT:arcsize:LAST:          Cur\\: %5.1lf%s");
@@ -680,7 +680,7 @@ sub zfs_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td valign='top' bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td class='td-valign-top'>\n");
 	}
 	@riglim = @{setup_riglim($rigid[1], $limit[1])};
 	undef(@tmp);
@@ -870,7 +870,7 @@ sub zfs_cgi {
 
 	if($title) {
 		push(@output, "    <tr>\n");
-		push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td>\n");
 	}
 	@riglim = @{setup_riglim($rigid[$e + 3], $limit[$e + 3])};
 	undef(@tmp);
@@ -1050,7 +1050,7 @@ sub zfs_cgi {
 
 	if($title) {
 		push(@output, "    </td>\n");
-		push(@output, "    <td bgcolor='" . $colors->{title_bg_color} . "'>\n");
+		push(@output, "    <td>\n");
 	}
 	@riglim = @{setup_riglim($rigid[$e + 3], $limit[$e + 3])};
 	undef(@tmp);
